diff --git a/.idea/.gitignore b/GAME/.idea/.gitignore
similarity index 100%
rename from .idea/.gitignore
rename to GAME/.idea/.gitignore
diff --git a/GAME/.idea/.name b/GAME/.idea/.name
new file mode 100644
index 0000000000000000000000000000000000000000..daec5296468fcf533a32f74becbda810db4423d0
--- /dev/null
+++ b/GAME/.idea/.name
@@ -0,0 +1 @@
+INSAGAME
\ No newline at end of file
diff --git a/.idea/INSAGAME.iml b/GAME/.idea/INSAGAME.iml
similarity index 100%
rename from .idea/INSAGAME.iml
rename to GAME/.idea/INSAGAME.iml
diff --git a/.idea/misc.xml b/GAME/.idea/misc.xml
similarity index 100%
rename from .idea/misc.xml
rename to GAME/.idea/misc.xml
diff --git a/.idea/modules.xml b/GAME/.idea/modules.xml
similarity index 100%
rename from .idea/modules.xml
rename to GAME/.idea/modules.xml
diff --git a/.idea/vcs.xml b/GAME/.idea/vcs.xml
similarity index 100%
rename from .idea/vcs.xml
rename to GAME/.idea/vcs.xml
diff --git a/CMakeLists.txt b/GAME/CMakeLists.txt
similarity index 100%
rename from CMakeLists.txt
rename to GAME/CMakeLists.txt
diff --git a/README.md b/GAME/README.md
similarity index 100%
rename from README.md
rename to GAME/README.md
diff --git a/cmake-build-debug/CMakeCache.txt b/GAME/cmake-build-debug/CMakeCache.txt
similarity index 98%
rename from cmake-build-debug/CMakeCache.txt
rename to GAME/cmake-build-debug/CMakeCache.txt
index 86a6fef7ab62667bf1a2c65b7d65154e856e5627..14587556a4daa084151b134631d903073bbe05dc 100644
--- a/cmake-build-debug/CMakeCache.txt
+++ b/GAME/cmake-build-debug/CMakeCache.txt
@@ -1,5 +1,5 @@
 # This is the CMakeCache file.
-# For build in directory: c:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug
+# For build in directory: c:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug
 # It was generated by CMake: C:/Program Files/JetBrains/CLion 2020.2.1/bin/cmake/win/bin/cmake.exe
 # You can edit this file to change values found and used by cmake.
 # If you do not want to change any of the values, simply exit the editor.
@@ -219,10 +219,10 @@ CMAKE_STRIP:FILEPATH=C:/TDM-GCC-64/bin/strip.exe
 CMAKE_VERBOSE_MAKEFILE:BOOL=FALSE
 
 //Value Computed by CMake
-INSAGAME_BINARY_DIR:STATIC=C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug
+INSAGAME_BINARY_DIR:STATIC=C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug
 
 //Value Computed by CMake
-INSAGAME_SOURCE_DIR:STATIC=C:/Users/Tiny/Desktop/INSAGAME
+INSAGAME_SOURCE_DIR:STATIC=C:/Users/Tiny/Desktop/game-insa-project
 
 
 ########################
@@ -234,7 +234,7 @@ CMAKE_ADDR2LINE-ADVANCED:INTERNAL=1
 //ADVANCED property for variable: CMAKE_AR
 CMAKE_AR-ADVANCED:INTERNAL=1
 //This is the directory where this CMakeCache.txt was created
-CMAKE_CACHEFILE_DIR:INTERNAL=c:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug
+CMAKE_CACHEFILE_DIR:INTERNAL=c:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug
 //Major version of cmake used to create the current loaded cache
 CMAKE_CACHE_MAJOR_VERSION:INTERNAL=3
 //Minor version of cmake used to create the current loaded cache
@@ -297,7 +297,7 @@ CMAKE_GENERATOR_PLATFORM:INTERNAL=
 CMAKE_GENERATOR_TOOLSET:INTERNAL=
 //Source directory with the top level CMakeLists.txt file for this
 // project
-CMAKE_HOME_DIRECTORY:INTERNAL=C:/Users/Tiny/Desktop/INSAGAME
+CMAKE_HOME_DIRECTORY:INTERNAL=C:/Users/Tiny/Desktop/game-insa-project
 //ADVANCED property for variable: CMAKE_LINKER
 CMAKE_LINKER-ADVANCED:INTERNAL=1
 //ADVANCED property for variable: CMAKE_MODULE_LINKER_FLAGS
diff --git a/cmake-build-debug/CMakeFiles/3.17.3/CMakeCCompiler.cmake b/GAME/cmake-build-debug/CMakeFiles/3.17.3/CMakeCCompiler.cmake
similarity index 100%
rename from cmake-build-debug/CMakeFiles/3.17.3/CMakeCCompiler.cmake
rename to GAME/cmake-build-debug/CMakeFiles/3.17.3/CMakeCCompiler.cmake
diff --git a/cmake-build-debug/CMakeFiles/3.17.3/CMakeDetermineCompilerABI_C.bin b/GAME/cmake-build-debug/CMakeFiles/3.17.3/CMakeDetermineCompilerABI_C.bin
similarity index 99%
rename from cmake-build-debug/CMakeFiles/3.17.3/CMakeDetermineCompilerABI_C.bin
rename to GAME/cmake-build-debug/CMakeFiles/3.17.3/CMakeDetermineCompilerABI_C.bin
index b513a4446d14c92fe8c5c91431e51ea2e3db1ffa..21469c5698511dba7ad7aa227b2bdd384213576b 100644
Binary files a/cmake-build-debug/CMakeFiles/3.17.3/CMakeDetermineCompilerABI_C.bin and b/GAME/cmake-build-debug/CMakeFiles/3.17.3/CMakeDetermineCompilerABI_C.bin differ
diff --git a/cmake-build-debug/CMakeFiles/3.17.3/CMakeRCCompiler.cmake b/GAME/cmake-build-debug/CMakeFiles/3.17.3/CMakeRCCompiler.cmake
similarity index 100%
rename from cmake-build-debug/CMakeFiles/3.17.3/CMakeRCCompiler.cmake
rename to GAME/cmake-build-debug/CMakeFiles/3.17.3/CMakeRCCompiler.cmake
diff --git a/cmake-build-debug/CMakeFiles/3.17.3/CMakeSystem.cmake b/GAME/cmake-build-debug/CMakeFiles/3.17.3/CMakeSystem.cmake
similarity index 100%
rename from cmake-build-debug/CMakeFiles/3.17.3/CMakeSystem.cmake
rename to GAME/cmake-build-debug/CMakeFiles/3.17.3/CMakeSystem.cmake
diff --git a/cmake-build-debug/CMakeFiles/3.17.3/CompilerIdC/CMakeCCompilerId.c b/GAME/cmake-build-debug/CMakeFiles/3.17.3/CompilerIdC/CMakeCCompilerId.c
similarity index 100%
rename from cmake-build-debug/CMakeFiles/3.17.3/CompilerIdC/CMakeCCompilerId.c
rename to GAME/cmake-build-debug/CMakeFiles/3.17.3/CompilerIdC/CMakeCCompilerId.c
diff --git a/cmake-build-debug/CMakeFiles/3.17.3/CompilerIdC/a.exe b/GAME/cmake-build-debug/CMakeFiles/3.17.3/CompilerIdC/a.exe
similarity index 99%
rename from cmake-build-debug/CMakeFiles/3.17.3/CompilerIdC/a.exe
rename to GAME/cmake-build-debug/CMakeFiles/3.17.3/CompilerIdC/a.exe
index 030b48b1691671db046cd7243eb576a996e2edb9..8c7ac04792770e8a7cac04b14925be4937f89cfd 100644
Binary files a/cmake-build-debug/CMakeFiles/3.17.3/CompilerIdC/a.exe and b/GAME/cmake-build-debug/CMakeFiles/3.17.3/CompilerIdC/a.exe differ
diff --git a/cmake-build-debug/CMakeFiles/CMakeDirectoryInformation.cmake b/GAME/cmake-build-debug/CMakeFiles/CMakeDirectoryInformation.cmake
similarity index 74%
rename from cmake-build-debug/CMakeFiles/CMakeDirectoryInformation.cmake
rename to GAME/cmake-build-debug/CMakeFiles/CMakeDirectoryInformation.cmake
index 9961d39e7d54e3837141983a97113e8b9f5551bc..9bd9be1979cf048cbaddec08543838bdd94d1847 100644
--- a/cmake-build-debug/CMakeFiles/CMakeDirectoryInformation.cmake
+++ b/GAME/cmake-build-debug/CMakeFiles/CMakeDirectoryInformation.cmake
@@ -2,8 +2,8 @@
 # Generated by "MinGW Makefiles" Generator, CMake Version 3.17
 
 # Relative path conversion top directories.
-set(CMAKE_RELATIVE_PATH_TOP_SOURCE "C:/Users/Tiny/Desktop/INSAGAME")
-set(CMAKE_RELATIVE_PATH_TOP_BINARY "C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug")
+set(CMAKE_RELATIVE_PATH_TOP_SOURCE "C:/Users/Tiny/Desktop/game-insa-project")
+set(CMAKE_RELATIVE_PATH_TOP_BINARY "C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug")
 
 # Force unix paths in dependencies.
 set(CMAKE_FORCE_UNIX_PATHS 1)
diff --git a/cmake-build-debug/CMakeFiles/CMakeOutput.log b/GAME/cmake-build-debug/CMakeFiles/CMakeOutput.log
similarity index 80%
rename from cmake-build-debug/CMakeFiles/CMakeOutput.log
rename to GAME/cmake-build-debug/CMakeFiles/CMakeOutput.log
index de4b8fff7fdb58a989137d43ba271076aa22d4d5..72eab2a1a50963e8892e19b8da38c82bdd2bd031 100644
--- a/cmake-build-debug/CMakeFiles/CMakeOutput.log
+++ b/GAME/cmake-build-debug/CMakeFiles/CMakeOutput.log
@@ -10,39 +10,39 @@ The output was:
 
 Compilation of the C compiler identification source "CMakeCCompilerId.c" produced "a.exe"
 
-The C compiler identification is GNU, found in "C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/CMakeFiles/3.17.3/CompilerIdC/a.exe"
+The C compiler identification is GNU, found in "C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/CMakeFiles/3.17.3/CompilerIdC/a.exe"
 
 Determining if the C compiler works passed with the following output:
-Change Dir: C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/CMakeFiles/CMakeTmp
+Change Dir: C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/CMakeFiles/CMakeTmp
 
-Run Build Command(s):C:/PROGRA~1/Git/mingw64/bin/make.exe cmTC_594b6/fast && C:/PROGRA~1/Git/mingw64/bin/make.exe  -f CMakeFiles\cmTC_594b6.dir\build.make CMakeFiles/cmTC_594b6.dir/build

-make.exe[1]: Entering directory 'C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/CMakeFiles/CMakeTmp'

-Building C object CMakeFiles/cmTC_594b6.dir/testCCompiler.c.obj

-C:\TDM-GCC-64\bin\gcc.exe    -o CMakeFiles\cmTC_594b6.dir\testCCompiler.c.obj   -c C:\Users\Tiny\Desktop\INSAGAME\cmake-build-debug\CMakeFiles\CMakeTmp\testCCompiler.c

-Linking C executable cmTC_594b6.exe

-"C:\Program Files\JetBrains\CLion 2020.2.1\bin\cmake\win\bin\cmake.exe" -E cmake_link_script CMakeFiles\cmTC_594b6.dir\link.txt --verbose=1

-"C:\Program Files\JetBrains\CLion 2020.2.1\bin\cmake\win\bin\cmake.exe" -E rm -f CMakeFiles\cmTC_594b6.dir/objects.a
-C:\TDM-GCC-64\bin\ar.exe cr CMakeFiles\cmTC_594b6.dir/objects.a @CMakeFiles\cmTC_594b6.dir\objects1.rsp
-C:\TDM-GCC-64\bin\gcc.exe      -Wl,--whole-archive CMakeFiles\cmTC_594b6.dir/objects.a -Wl,--no-whole-archive  -o cmTC_594b6.exe -Wl,--out-implib,libcmTC_594b6.dll.a -Wl,--major-image-version,0,--minor-image-version,0 @CMakeFiles\cmTC_594b6.dir\linklibs.rsp
-make.exe[1]: Leaving directory 'C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/CMakeFiles/CMakeTmp'

+Run Build Command(s):C:/PROGRA~1/Git/mingw64/bin/make.exe cmTC_a9f84/fast && C:/PROGRA~1/Git/mingw64/bin/make.exe  -f CMakeFiles\cmTC_a9f84.dir\build.make CMakeFiles/cmTC_a9f84.dir/build

+make.exe[1]: Entering directory 'C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/CMakeFiles/CMakeTmp'

+Building C object CMakeFiles/cmTC_a9f84.dir/testCCompiler.c.obj

+C:\TDM-GCC-64\bin\gcc.exe    -o CMakeFiles\cmTC_a9f84.dir\testCCompiler.c.obj   -c C:\Users\Tiny\Desktop\game-insa-project\cmake-build-debug\CMakeFiles\CMakeTmp\testCCompiler.c

+Linking C executable cmTC_a9f84.exe

+"C:\Program Files\JetBrains\CLion 2020.2.1\bin\cmake\win\bin\cmake.exe" -E cmake_link_script CMakeFiles\cmTC_a9f84.dir\link.txt --verbose=1

+"C:\Program Files\JetBrains\CLion 2020.2.1\bin\cmake\win\bin\cmake.exe" -E rm -f CMakeFiles\cmTC_a9f84.dir/objects.a
+C:\TDM-GCC-64\bin\ar.exe cr CMakeFiles\cmTC_a9f84.dir/objects.a @CMakeFiles\cmTC_a9f84.dir\objects1.rsp
+C:\TDM-GCC-64\bin\gcc.exe      -Wl,--whole-archive CMakeFiles\cmTC_a9f84.dir/objects.a -Wl,--no-whole-archive  -o cmTC_a9f84.exe -Wl,--out-implib,libcmTC_a9f84.dll.a -Wl,--major-image-version,0,--minor-image-version,0 @CMakeFiles\cmTC_a9f84.dir\linklibs.rsp
+make.exe[1]: Leaving directory 'C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/CMakeFiles/CMakeTmp'

 
 
 
 Detecting C compiler ABI info compiled with the following output:
-Change Dir: C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/CMakeFiles/CMakeTmp
+Change Dir: C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/CMakeFiles/CMakeTmp
 
-Run Build Command(s):C:/PROGRA~1/Git/mingw64/bin/make.exe cmTC_3dd80/fast && C:/PROGRA~1/Git/mingw64/bin/make.exe  -f CMakeFiles\cmTC_3dd80.dir\build.make CMakeFiles/cmTC_3dd80.dir/build

-make.exe[1]: Entering directory 'C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/CMakeFiles/CMakeTmp'

-Building C object CMakeFiles/cmTC_3dd80.dir/CMakeCCompilerABI.c.obj

-C:\TDM-GCC-64\bin\gcc.exe   -v -o CMakeFiles\cmTC_3dd80.dir\CMakeCCompilerABI.c.obj   -c "C:\Program Files\JetBrains\CLion 2020.2.1\bin\cmake\win\share\cmake-3.17\Modules\CMakeCCompilerABI.c"

+Run Build Command(s):C:/PROGRA~1/Git/mingw64/bin/make.exe cmTC_65673/fast && C:/PROGRA~1/Git/mingw64/bin/make.exe  -f CMakeFiles\cmTC_65673.dir\build.make CMakeFiles/cmTC_65673.dir/build

+make.exe[1]: Entering directory 'C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/CMakeFiles/CMakeTmp'

+Building C object CMakeFiles/cmTC_65673.dir/CMakeCCompilerABI.c.obj

+C:\TDM-GCC-64\bin\gcc.exe   -v -o CMakeFiles\cmTC_65673.dir\CMakeCCompilerABI.c.obj   -c "C:\Program Files\JetBrains\CLion 2020.2.1\bin\cmake\win\share\cmake-3.17\Modules\CMakeCCompilerABI.c"

 Using built-in specs.

 COLLECT_GCC=C:\TDM-GCC-64\bin\gcc.exe

 Target: x86_64-w64-mingw32

 Configured with: ../../../src/gcc-git-9.2.0/configure --build=x86_64-w64-mingw32 --enable-targets=all --enable-languages=ada,c,c++,fortran,lto,objc,obj-c++ --enable-libgomp --enable-lto --enable-graphite --enable-cxx-flags=-DWINPTHREAD_STATIC --disable-build-with-cxx --disable-build-poststage1-with-cxx --enable-libstdcxx-debug --enable-threads=posix --enable-version-specific-runtime-libs --enable-fully-dynamic-string --enable-libstdcxx-threads --enable-libstdcxx-time --with-gnu-ld --disable-werror --disable-nls --disable-win32-registry --enable-large-address-aware --disable-rpath --disable-symvers --prefix=/mingw64tdm --with-local-prefix=/mingw64tdm --with-pkgversion=tdm64-1 --with-bugurl=http://tdm-gcc.tdragon.net/bugs

 Thread model: posix

 gcc version 9.2.0 (tdm64-1) 

-COLLECT_GCC_OPTIONS='-v' '-o' 'CMakeFiles\cmTC_3dd80.dir\CMakeCCompilerABI.c.obj' '-c' '-mtune=generic' '-march=x86-64'

- C:/TDM-GCC-64/bin/../libexec/gcc/x86_64-w64-mingw32/9.2.0/cc1.exe -quiet -v -iprefix C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/ -D_REENTRANT C:\Program Files\JetBrains\CLion 2020.2.1\bin\cmake\win\share\cmake-3.17\Modules\CMakeCCompilerABI.c -quiet -dumpbase CMakeCCompilerABI.c -mtune=generic -march=x86-64 -auxbase-strip CMakeFiles\cmTC_3dd80.dir\CMakeCCompilerABI.c.obj -version -o C:\Users\Tiny\AppData\Local\Temp\ccwzDVZM.s

+COLLECT_GCC_OPTIONS='-v' '-o' 'CMakeFiles\cmTC_65673.dir\CMakeCCompilerABI.c.obj' '-c' '-mtune=generic' '-march=x86-64'

+ C:/TDM-GCC-64/bin/../libexec/gcc/x86_64-w64-mingw32/9.2.0/cc1.exe -quiet -v -iprefix C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/ -D_REENTRANT C:\Program Files\JetBrains\CLion 2020.2.1\bin\cmake\win\share\cmake-3.17\Modules\CMakeCCompilerABI.c -quiet -dumpbase CMakeCCompilerABI.c -mtune=generic -march=x86-64 -auxbase-strip CMakeFiles\cmTC_65673.dir\CMakeCCompilerABI.c.obj -version -o C:\Users\Tiny\AppData\Local\Temp\ccbZOMlV.s

 GNU C17 (tdm64-1) version 9.2.0 (x86_64-w64-mingw32)

 	compiled by GNU C version 9.2.0, GMP version 6.1.0, MPFR version 3.1.4, MPC version 1.0.3, isl version isl-0.18-GMP

 

@@ -63,17 +63,17 @@ GNU C17 (tdm64-1) version 9.2.0 (x86_64-w64-mingw32)
 

 GGC heuristics: --param ggc-min-expand=100 --param ggc-min-heapsize=131072

 Compiler executable checksum: 28379e31cc2f1f6d7a657691ed425dfd

-COLLECT_GCC_OPTIONS='-v' '-o' 'CMakeFiles\cmTC_3dd80.dir\CMakeCCompilerABI.c.obj' '-c' '-mtune=generic' '-march=x86-64'

- C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/bin/as.exe -v -o CMakeFiles\cmTC_3dd80.dir\CMakeCCompilerABI.c.obj C:\Users\Tiny\AppData\Local\Temp\ccwzDVZM.s

+COLLECT_GCC_OPTIONS='-v' '-o' 'CMakeFiles\cmTC_65673.dir\CMakeCCompilerABI.c.obj' '-c' '-mtune=generic' '-march=x86-64'

+ C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/bin/as.exe -v -o CMakeFiles\cmTC_65673.dir\CMakeCCompilerABI.c.obj C:\Users\Tiny\AppData\Local\Temp\ccbZOMlV.s

 GNU assembler version 2.33.1 (x86_64-w64-mingw32) using BFD version (GNU Binutils) 2.33.1

 COMPILER_PATH=C:/TDM-GCC-64/bin/../libexec/gcc/x86_64-w64-mingw32/9.2.0/;C:/TDM-GCC-64/bin/../libexec/gcc/;C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/bin/

 LIBRARY_PATH=C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/;C:/TDM-GCC-64/bin/../lib/gcc/;C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/lib/../lib/;C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../lib/;C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/lib/;C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../

-COLLECT_GCC_OPTIONS='-v' '-o' 'CMakeFiles\cmTC_3dd80.dir\CMakeCCompilerABI.c.obj' '-c' '-mtune=generic' '-march=x86-64'

-Linking C executable cmTC_3dd80.exe

-"C:\Program Files\JetBrains\CLion 2020.2.1\bin\cmake\win\bin\cmake.exe" -E cmake_link_script CMakeFiles\cmTC_3dd80.dir\link.txt --verbose=1

-"C:\Program Files\JetBrains\CLion 2020.2.1\bin\cmake\win\bin\cmake.exe" -E rm -f CMakeFiles\cmTC_3dd80.dir/objects.a
-C:\TDM-GCC-64\bin\ar.exe cr CMakeFiles\cmTC_3dd80.dir/objects.a @CMakeFiles\cmTC_3dd80.dir\objects1.rsp
-C:\TDM-GCC-64\bin\gcc.exe     -v -Wl,--whole-archive CMakeFiles\cmTC_3dd80.dir/objects.a -Wl,--no-whole-archive  -o cmTC_3dd80.exe -Wl,--out-implib,libcmTC_3dd80.dll.a -Wl,--major-image-version,0,--minor-image-version,0 
+COLLECT_GCC_OPTIONS='-v' '-o' 'CMakeFiles\cmTC_65673.dir\CMakeCCompilerABI.c.obj' '-c' '-mtune=generic' '-march=x86-64'

+Linking C executable cmTC_65673.exe

+"C:\Program Files\JetBrains\CLion 2020.2.1\bin\cmake\win\bin\cmake.exe" -E cmake_link_script CMakeFiles\cmTC_65673.dir\link.txt --verbose=1

+"C:\Program Files\JetBrains\CLion 2020.2.1\bin\cmake\win\bin\cmake.exe" -E rm -f CMakeFiles\cmTC_65673.dir/objects.a
+C:\TDM-GCC-64\bin\ar.exe cr CMakeFiles\cmTC_65673.dir/objects.a @CMakeFiles\cmTC_65673.dir\objects1.rsp
+C:\TDM-GCC-64\bin\gcc.exe     -v -Wl,--whole-archive CMakeFiles\cmTC_65673.dir/objects.a -Wl,--no-whole-archive  -o cmTC_65673.exe -Wl,--out-implib,libcmTC_65673.dll.a -Wl,--major-image-version,0,--minor-image-version,0 
 Using built-in specs.

 COLLECT_GCC=C:\TDM-GCC-64\bin\gcc.exe

 COLLECT_LTO_WRAPPER=C:/TDM-GCC-64/bin/../libexec/gcc/x86_64-w64-mingw32/9.2.0/lto-wrapper.exe

@@ -83,10 +83,10 @@ Thread model: posix
 gcc version 9.2.0 (tdm64-1) 

 COMPILER_PATH=C:/TDM-GCC-64/bin/../libexec/gcc/x86_64-w64-mingw32/9.2.0/;C:/TDM-GCC-64/bin/../libexec/gcc/;C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/bin/

 LIBRARY_PATH=C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/;C:/TDM-GCC-64/bin/../lib/gcc/;C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/lib/../lib/;C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../lib/;C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/lib/;C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../

-COLLECT_GCC_OPTIONS='-v' '-o' 'cmTC_3dd80.exe' '-mtune=generic' '-march=x86-64'

- C:/TDM-GCC-64/bin/../libexec/gcc/x86_64-w64-mingw32/9.2.0/collect2.exe -plugin C:/TDM-GCC-64/bin/../libexec/gcc/x86_64-w64-mingw32/9.2.0/liblto_plugin-0.dll -plugin-opt=C:/TDM-GCC-64/bin/../libexec/gcc/x86_64-w64-mingw32/9.2.0/lto-wrapper.exe -plugin-opt=-fresolution=C:\Users\Tiny\AppData\Local\Temp\cc92QrAp.res -plugin-opt=-pass-through=-lmingw32 -plugin-opt=-pass-through=-lgcc -plugin-opt=-pass-through=-lmoldname -plugin-opt=-pass-through=-lmingwex -plugin-opt=-pass-through=-lmsvcrt -plugin-opt=-pass-through=-lpthread -plugin-opt=-pass-through=-ladvapi32 -plugin-opt=-pass-through=-lshell32 -plugin-opt=-pass-through=-luser32 -plugin-opt=-pass-through=-lkernel32 -plugin-opt=-pass-through=-lmingw32 -plugin-opt=-pass-through=-lgcc -plugin-opt=-pass-through=-lmoldname -plugin-opt=-pass-through=-lmingwex -plugin-opt=-pass-through=-lmsvcrt -m i386pep --exclude-libs=libpthread.a -Bdynamic -o cmTC_3dd80.exe C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/lib/../lib/crt2.o C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/crtbegin.o -LC:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0 -LC:/TDM-GCC-64/bin/../lib/gcc -LC:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/lib/../lib -LC:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../lib -LC:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/lib -LC:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../.. --whole-archive CMakeFiles\cmTC_3dd80.dir/objects.a --no-whole-archive --out-implib libcmTC_3dd80.dll.a --major-image-version 0 --minor-image-version 0 -lmingw32 -lgcc -lmoldname -lmingwex -lmsvcrt -lpthread -ladvapi32 -lshell32 -luser32 -lkernel32 -lmingw32 -lgcc -lmoldname -lmingwex -lmsvcrt C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/lib/../lib/default-manifest.o C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/crtend.o

-COLLECT_GCC_OPTIONS='-v' '-o' 'cmTC_3dd80.exe' '-mtune=generic' '-march=x86-64'

-make.exe[1]: Leaving directory 'C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/CMakeFiles/CMakeTmp'

+COLLECT_GCC_OPTIONS='-v' '-o' 'cmTC_65673.exe' '-mtune=generic' '-march=x86-64'

+ C:/TDM-GCC-64/bin/../libexec/gcc/x86_64-w64-mingw32/9.2.0/collect2.exe -plugin C:/TDM-GCC-64/bin/../libexec/gcc/x86_64-w64-mingw32/9.2.0/liblto_plugin-0.dll -plugin-opt=C:/TDM-GCC-64/bin/../libexec/gcc/x86_64-w64-mingw32/9.2.0/lto-wrapper.exe -plugin-opt=-fresolution=C:\Users\Tiny\AppData\Local\Temp\ccZPFKRs.res -plugin-opt=-pass-through=-lmingw32 -plugin-opt=-pass-through=-lgcc -plugin-opt=-pass-through=-lmoldname -plugin-opt=-pass-through=-lmingwex -plugin-opt=-pass-through=-lmsvcrt -plugin-opt=-pass-through=-lpthread -plugin-opt=-pass-through=-ladvapi32 -plugin-opt=-pass-through=-lshell32 -plugin-opt=-pass-through=-luser32 -plugin-opt=-pass-through=-lkernel32 -plugin-opt=-pass-through=-lmingw32 -plugin-opt=-pass-through=-lgcc -plugin-opt=-pass-through=-lmoldname -plugin-opt=-pass-through=-lmingwex -plugin-opt=-pass-through=-lmsvcrt -m i386pep --exclude-libs=libpthread.a -Bdynamic -o cmTC_65673.exe C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/lib/../lib/crt2.o C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/crtbegin.o -LC:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0 -LC:/TDM-GCC-64/bin/../lib/gcc -LC:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/lib/../lib -LC:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../lib -LC:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/lib -LC:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../.. --whole-archive CMakeFiles\cmTC_65673.dir/objects.a --no-whole-archive --out-implib libcmTC_65673.dll.a --major-image-version 0 --minor-image-version 0 -lmingw32 -lgcc -lmoldname -lmingwex -lmsvcrt -lpthread -ladvapi32 -lshell32 -luser32 -lkernel32 -lmingw32 -lgcc -lmoldname -lmingwex -lmsvcrt C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/lib/../lib/default-manifest.o C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/crtend.o

+COLLECT_GCC_OPTIONS='-v' '-o' 'cmTC_65673.exe' '-mtune=generic' '-march=x86-64'

+make.exe[1]: Leaving directory 'C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/CMakeFiles/CMakeTmp'

 
 
 
@@ -107,20 +107,20 @@ Parsed C implicit include dir info from above output: rv=done
 
 Parsed C implicit link information from above output:
   link line regex: [^( *|.*[/\])(ld\.exe|CMAKE_LINK_STARTFILE-NOTFOUND|([^/\]+-)?ld|collect2)[^/\]*( |$)]
-  ignore line: [Change Dir: C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/CMakeFiles/CMakeTmp]
+  ignore line: [Change Dir: C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/CMakeFiles/CMakeTmp]
   ignore line: []
-  ignore line: [Run Build Command(s):C:/PROGRA~1/Git/mingw64/bin/make.exe cmTC_3dd80/fast && C:/PROGRA~1/Git/mingw64/bin/make.exe  -f CMakeFiles\cmTC_3dd80.dir\build.make CMakeFiles/cmTC_3dd80.dir/build]
-  ignore line: [make.exe[1]: Entering directory 'C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/CMakeFiles/CMakeTmp']
-  ignore line: [Building C object CMakeFiles/cmTC_3dd80.dir/CMakeCCompilerABI.c.obj]
-  ignore line: [C:\TDM-GCC-64\bin\gcc.exe   -v -o CMakeFiles\cmTC_3dd80.dir\CMakeCCompilerABI.c.obj   -c "C:\Program Files\JetBrains\CLion 2020.2.1\bin\cmake\win\share\cmake-3.17\Modules\CMakeCCompilerABI.c"]
+  ignore line: [Run Build Command(s):C:/PROGRA~1/Git/mingw64/bin/make.exe cmTC_65673/fast && C:/PROGRA~1/Git/mingw64/bin/make.exe  -f CMakeFiles\cmTC_65673.dir\build.make CMakeFiles/cmTC_65673.dir/build]
+  ignore line: [make.exe[1]: Entering directory 'C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/CMakeFiles/CMakeTmp']
+  ignore line: [Building C object CMakeFiles/cmTC_65673.dir/CMakeCCompilerABI.c.obj]
+  ignore line: [C:\TDM-GCC-64\bin\gcc.exe   -v -o CMakeFiles\cmTC_65673.dir\CMakeCCompilerABI.c.obj   -c "C:\Program Files\JetBrains\CLion 2020.2.1\bin\cmake\win\share\cmake-3.17\Modules\CMakeCCompilerABI.c"]
   ignore line: [Using built-in specs.]
   ignore line: [COLLECT_GCC=C:\TDM-GCC-64\bin\gcc.exe]
   ignore line: [Target: x86_64-w64-mingw32]
   ignore line: [Configured with: ../../../src/gcc-git-9.2.0/configure --build=x86_64-w64-mingw32 --enable-targets=all --enable-languages=ada,c,c++,fortran,lto,objc,obj-c++ --enable-libgomp --enable-lto --enable-graphite --enable-cxx-flags=-DWINPTHREAD_STATIC --disable-build-with-cxx --disable-build-poststage1-with-cxx --enable-libstdcxx-debug --enable-threads=posix --enable-version-specific-runtime-libs --enable-fully-dynamic-string --enable-libstdcxx-threads --enable-libstdcxx-time --with-gnu-ld --disable-werror --disable-nls --disable-win32-registry --enable-large-address-aware --disable-rpath --disable-symvers --prefix=/mingw64tdm --with-local-prefix=/mingw64tdm --with-pkgversion=tdm64-1 --with-bugurl=http://tdm-gcc.tdragon.net/bugs]
   ignore line: [Thread model: posix]
   ignore line: [gcc version 9.2.0 (tdm64-1) ]
-  ignore line: [COLLECT_GCC_OPTIONS='-v' '-o' 'CMakeFiles\cmTC_3dd80.dir\CMakeCCompilerABI.c.obj' '-c' '-mtune=generic' '-march=x86-64']
-  ignore line: [ C:/TDM-GCC-64/bin/../libexec/gcc/x86_64-w64-mingw32/9.2.0/cc1.exe -quiet -v -iprefix C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/ -D_REENTRANT C:\Program Files\JetBrains\CLion 2020.2.1\bin\cmake\win\share\cmake-3.17\Modules\CMakeCCompilerABI.c -quiet -dumpbase CMakeCCompilerABI.c -mtune=generic -march=x86-64 -auxbase-strip CMakeFiles\cmTC_3dd80.dir\CMakeCCompilerABI.c.obj -version -o C:\Users\Tiny\AppData\Local\Temp\ccwzDVZM.s]
+  ignore line: [COLLECT_GCC_OPTIONS='-v' '-o' 'CMakeFiles\cmTC_65673.dir\CMakeCCompilerABI.c.obj' '-c' '-mtune=generic' '-march=x86-64']
+  ignore line: [ C:/TDM-GCC-64/bin/../libexec/gcc/x86_64-w64-mingw32/9.2.0/cc1.exe -quiet -v -iprefix C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/ -D_REENTRANT C:\Program Files\JetBrains\CLion 2020.2.1\bin\cmake\win\share\cmake-3.17\Modules\CMakeCCompilerABI.c -quiet -dumpbase CMakeCCompilerABI.c -mtune=generic -march=x86-64 -auxbase-strip CMakeFiles\cmTC_65673.dir\CMakeCCompilerABI.c.obj -version -o C:\Users\Tiny\AppData\Local\Temp\ccbZOMlV.s]
   ignore line: [GNU C17 (tdm64-1) version 9.2.0 (x86_64-w64-mingw32)]
   ignore line: [	compiled by GNU C version 9.2.0  GMP version 6.1.0  MPFR version 3.1.4  MPC version 1.0.3  isl version isl-0.18-GMP]
   ignore line: []
@@ -141,8 +141,8 @@ Parsed C implicit link information from above output:
   ignore line: []
   ignore line: [GGC heuristics: --param ggc-min-expand=100 --param ggc-min-heapsize=131072]
   ignore line: [Compiler executable checksum: 28379e31cc2f1f6d7a657691ed425dfd]
-  ignore line: [COLLECT_GCC_OPTIONS='-v' '-o' 'CMakeFiles\cmTC_3dd80.dir\CMakeCCompilerABI.c.obj' '-c' '-mtune=generic' '-march=x86-64']
-  ignore line: [ C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/bin/as.exe -v -o CMakeFiles\cmTC_3dd80.dir\CMakeCCompilerABI.c.obj C:\Users\Tiny\AppData\Local\Temp\ccwzDVZM.s]
+  ignore line: [COLLECT_GCC_OPTIONS='-v' '-o' 'CMakeFiles\cmTC_65673.dir\CMakeCCompilerABI.c.obj' '-c' '-mtune=generic' '-march=x86-64']
+  ignore line: [ C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/bin/as.exe -v -o CMakeFiles\cmTC_65673.dir\CMakeCCompilerABI.c.obj C:\Users\Tiny\AppData\Local\Temp\ccbZOMlV.s]
   ignore line: [GNU assembler version 2.33.1 (x86_64-w64-mingw32) using BFD version (GNU Binutils) 2.33.1]
   ignore line: [COMPILER_PATH=C:/TDM-GCC-64/bin/../libexec/gcc/x86_64-w64-mingw32/9.2.0/]
   ignore line: [C:/TDM-GCC-64/bin/../libexec/gcc/]
@@ -153,12 +153,12 @@ Parsed C implicit link information from above output:
   ignore line: [C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../lib/]
   ignore line: [C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/lib/]
   ignore line: [C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../]
-  ignore line: [COLLECT_GCC_OPTIONS='-v' '-o' 'CMakeFiles\cmTC_3dd80.dir\CMakeCCompilerABI.c.obj' '-c' '-mtune=generic' '-march=x86-64']
-  ignore line: [Linking C executable cmTC_3dd80.exe]
-  ignore line: ["C:\Program Files\JetBrains\CLion 2020.2.1\bin\cmake\win\bin\cmake.exe" -E cmake_link_script CMakeFiles\cmTC_3dd80.dir\link.txt --verbose=1]
-  ignore line: ["C:\Program Files\JetBrains\CLion 2020.2.1\bin\cmake\win\bin\cmake.exe" -E rm -f CMakeFiles\cmTC_3dd80.dir/objects.a]
-  ignore line: [C:\TDM-GCC-64\bin\ar.exe cr CMakeFiles\cmTC_3dd80.dir/objects.a @CMakeFiles\cmTC_3dd80.dir\objects1.rsp]
-  ignore line: [C:\TDM-GCC-64\bin\gcc.exe     -v -Wl --whole-archive CMakeFiles\cmTC_3dd80.dir/objects.a -Wl --no-whole-archive  -o cmTC_3dd80.exe -Wl --out-implib libcmTC_3dd80.dll.a -Wl --major-image-version 0 --minor-image-version 0 ]
+  ignore line: [COLLECT_GCC_OPTIONS='-v' '-o' 'CMakeFiles\cmTC_65673.dir\CMakeCCompilerABI.c.obj' '-c' '-mtune=generic' '-march=x86-64']
+  ignore line: [Linking C executable cmTC_65673.exe]
+  ignore line: ["C:\Program Files\JetBrains\CLion 2020.2.1\bin\cmake\win\bin\cmake.exe" -E cmake_link_script CMakeFiles\cmTC_65673.dir\link.txt --verbose=1]
+  ignore line: ["C:\Program Files\JetBrains\CLion 2020.2.1\bin\cmake\win\bin\cmake.exe" -E rm -f CMakeFiles\cmTC_65673.dir/objects.a]
+  ignore line: [C:\TDM-GCC-64\bin\ar.exe cr CMakeFiles\cmTC_65673.dir/objects.a @CMakeFiles\cmTC_65673.dir\objects1.rsp]
+  ignore line: [C:\TDM-GCC-64\bin\gcc.exe     -v -Wl --whole-archive CMakeFiles\cmTC_65673.dir/objects.a -Wl --no-whole-archive  -o cmTC_65673.exe -Wl --out-implib libcmTC_65673.dll.a -Wl --major-image-version 0 --minor-image-version 0 ]
   ignore line: [Using built-in specs.]
   ignore line: [COLLECT_GCC=C:\TDM-GCC-64\bin\gcc.exe]
   ignore line: [COLLECT_LTO_WRAPPER=C:/TDM-GCC-64/bin/../libexec/gcc/x86_64-w64-mingw32/9.2.0/lto-wrapper.exe]
@@ -175,13 +175,13 @@ Parsed C implicit link information from above output:
   ignore line: [C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../lib/]
   ignore line: [C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/lib/]
   ignore line: [C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../]
-  ignore line: [COLLECT_GCC_OPTIONS='-v' '-o' 'cmTC_3dd80.exe' '-mtune=generic' '-march=x86-64']
-  link line: [ C:/TDM-GCC-64/bin/../libexec/gcc/x86_64-w64-mingw32/9.2.0/collect2.exe -plugin C:/TDM-GCC-64/bin/../libexec/gcc/x86_64-w64-mingw32/9.2.0/liblto_plugin-0.dll -plugin-opt=C:/TDM-GCC-64/bin/../libexec/gcc/x86_64-w64-mingw32/9.2.0/lto-wrapper.exe -plugin-opt=-fresolution=C:\Users\Tiny\AppData\Local\Temp\cc92QrAp.res -plugin-opt=-pass-through=-lmingw32 -plugin-opt=-pass-through=-lgcc -plugin-opt=-pass-through=-lmoldname -plugin-opt=-pass-through=-lmingwex -plugin-opt=-pass-through=-lmsvcrt -plugin-opt=-pass-through=-lpthread -plugin-opt=-pass-through=-ladvapi32 -plugin-opt=-pass-through=-lshell32 -plugin-opt=-pass-through=-luser32 -plugin-opt=-pass-through=-lkernel32 -plugin-opt=-pass-through=-lmingw32 -plugin-opt=-pass-through=-lgcc -plugin-opt=-pass-through=-lmoldname -plugin-opt=-pass-through=-lmingwex -plugin-opt=-pass-through=-lmsvcrt -m i386pep --exclude-libs=libpthread.a -Bdynamic -o cmTC_3dd80.exe C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/lib/../lib/crt2.o C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/crtbegin.o -LC:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0 -LC:/TDM-GCC-64/bin/../lib/gcc -LC:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/lib/../lib -LC:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../lib -LC:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/lib -LC:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../.. --whole-archive CMakeFiles\cmTC_3dd80.dir/objects.a --no-whole-archive --out-implib libcmTC_3dd80.dll.a --major-image-version 0 --minor-image-version 0 -lmingw32 -lgcc -lmoldname -lmingwex -lmsvcrt -lpthread -ladvapi32 -lshell32 -luser32 -lkernel32 -lmingw32 -lgcc -lmoldname -lmingwex -lmsvcrt C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/lib/../lib/default-manifest.o C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/crtend.o]
+  ignore line: [COLLECT_GCC_OPTIONS='-v' '-o' 'cmTC_65673.exe' '-mtune=generic' '-march=x86-64']
+  link line: [ C:/TDM-GCC-64/bin/../libexec/gcc/x86_64-w64-mingw32/9.2.0/collect2.exe -plugin C:/TDM-GCC-64/bin/../libexec/gcc/x86_64-w64-mingw32/9.2.0/liblto_plugin-0.dll -plugin-opt=C:/TDM-GCC-64/bin/../libexec/gcc/x86_64-w64-mingw32/9.2.0/lto-wrapper.exe -plugin-opt=-fresolution=C:\Users\Tiny\AppData\Local\Temp\ccZPFKRs.res -plugin-opt=-pass-through=-lmingw32 -plugin-opt=-pass-through=-lgcc -plugin-opt=-pass-through=-lmoldname -plugin-opt=-pass-through=-lmingwex -plugin-opt=-pass-through=-lmsvcrt -plugin-opt=-pass-through=-lpthread -plugin-opt=-pass-through=-ladvapi32 -plugin-opt=-pass-through=-lshell32 -plugin-opt=-pass-through=-luser32 -plugin-opt=-pass-through=-lkernel32 -plugin-opt=-pass-through=-lmingw32 -plugin-opt=-pass-through=-lgcc -plugin-opt=-pass-through=-lmoldname -plugin-opt=-pass-through=-lmingwex -plugin-opt=-pass-through=-lmsvcrt -m i386pep --exclude-libs=libpthread.a -Bdynamic -o cmTC_65673.exe C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/lib/../lib/crt2.o C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/crtbegin.o -LC:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0 -LC:/TDM-GCC-64/bin/../lib/gcc -LC:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/lib/../lib -LC:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../lib -LC:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/lib -LC:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../.. --whole-archive CMakeFiles\cmTC_65673.dir/objects.a --no-whole-archive --out-implib libcmTC_65673.dll.a --major-image-version 0 --minor-image-version 0 -lmingw32 -lgcc -lmoldname -lmingwex -lmsvcrt -lpthread -ladvapi32 -lshell32 -luser32 -lkernel32 -lmingw32 -lgcc -lmoldname -lmingwex -lmsvcrt C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/lib/../lib/default-manifest.o C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/crtend.o]
     arg [C:/TDM-GCC-64/bin/../libexec/gcc/x86_64-w64-mingw32/9.2.0/collect2.exe] ==> ignore
     arg [-plugin] ==> ignore
     arg [C:/TDM-GCC-64/bin/../libexec/gcc/x86_64-w64-mingw32/9.2.0/liblto_plugin-0.dll] ==> ignore
     arg [-plugin-opt=C:/TDM-GCC-64/bin/../libexec/gcc/x86_64-w64-mingw32/9.2.0/lto-wrapper.exe] ==> ignore
-    arg [-plugin-opt=-fresolution=C:\Users\Tiny\AppData\Local\Temp\cc92QrAp.res] ==> ignore
+    arg [-plugin-opt=-fresolution=C:\Users\Tiny\AppData\Local\Temp\ccZPFKRs.res] ==> ignore
     arg [-plugin-opt=-pass-through=-lmingw32] ==> ignore
     arg [-plugin-opt=-pass-through=-lgcc] ==> ignore
     arg [-plugin-opt=-pass-through=-lmoldname] ==> ignore
@@ -202,7 +202,7 @@ Parsed C implicit link information from above output:
     arg [--exclude-libs=libpthread.a] ==> ignore
     arg [-Bdynamic] ==> ignore
     arg [-o] ==> ignore
-    arg [cmTC_3dd80.exe] ==> ignore
+    arg [cmTC_65673.exe] ==> ignore
     arg [C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/lib/../lib/crt2.o] ==> ignore
     arg [C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/crtbegin.o] ==> ignore
     arg [-LC:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0] ==> dir [C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0]
@@ -212,10 +212,10 @@ Parsed C implicit link information from above output:
     arg [-LC:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/lib] ==> dir [C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/lib]
     arg [-LC:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../..] ==> dir [C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../..]
     arg [--whole-archive] ==> ignore
-    arg [CMakeFiles\cmTC_3dd80.dir/objects.a] ==> ignore
+    arg [CMakeFiles\cmTC_65673.dir/objects.a] ==> ignore
     arg [--no-whole-archive] ==> ignore
     arg [--out-implib] ==> ignore
-    arg [libcmTC_3dd80.dll.a] ==> ignore
+    arg [libcmTC_65673.dll.a] ==> ignore
     arg [--major-image-version] ==> ignore
     arg [0] ==> ignore
     arg [--minor-image-version] ==> ignore
diff --git a/cmake-build-debug/CMakeFiles/INSAGAME.dir/C.includecache b/GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/C.includecache
similarity index 77%
rename from cmake-build-debug/CMakeFiles/INSAGAME.dir/C.includecache
rename to GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/C.includecache
index 1c4ae5986de7ba2aeaec06c0f5308b69cfa6886e..436a0464719db5e335b19d5854b702fd481c9bf4 100644
--- a/cmake-build-debug/CMakeFiles/INSAGAME.dir/C.includecache
+++ b/GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/C.includecache
@@ -6,13 +6,11 @@
 
 #IncludeRegexTransform: 
 
-C:/Users/Tiny/Desktop/INSAGAME/main.c
+C:/Users/Tiny/Desktop/game-insa-project/main.c
 stdio.h
 -
 SDL2/SDL.h
 -
-SDL2/SDL_timer.h
--
 SDL2/SDL_image.h
 -
 
diff --git a/cmake-build-debug/CMakeFiles/INSAGAME.dir/DependInfo.cmake b/GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/DependInfo.cmake
similarity index 75%
rename from cmake-build-debug/CMakeFiles/INSAGAME.dir/DependInfo.cmake
rename to GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/DependInfo.cmake
index 3714dc4def7479d9cec8e598cda618ce141e5044..ba7c64ca681185b66f5aa4495eb8b9fadf30dc05 100644
--- a/cmake-build-debug/CMakeFiles/INSAGAME.dir/DependInfo.cmake
+++ b/GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/DependInfo.cmake
@@ -4,7 +4,7 @@ set(CMAKE_DEPENDS_LANGUAGES
   )
 # The set of files for implicit dependencies of each language:
 set(CMAKE_DEPENDS_CHECK_C
-  "C:/Users/Tiny/Desktop/INSAGAME/main.c" "C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/main.c.obj"
+  "C:/Users/Tiny/Desktop/game-insa-project/main.c" "C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/CMakeFiles/INSAGAME.dir/main.c.obj"
   )
 set(CMAKE_C_COMPILER_ID "GNU")
 
diff --git a/cmake-build-debug/CMakeFiles/INSAGAME.dir/build.make b/GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/build.make
similarity index 77%
rename from cmake-build-debug/CMakeFiles/INSAGAME.dir/build.make
rename to GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/build.make
index 983dc552f3a8077e4ca88aaf11b1c732f5f920de..f92560e53d770202e21ac2abf832610a61702488 100644
--- a/cmake-build-debug/CMakeFiles/INSAGAME.dir/build.make
+++ b/GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/build.make
@@ -62,10 +62,10 @@ RM = "C:\Program Files\JetBrains\CLion 2020.2.1\bin\cmake\win\bin\cmake.exe" -E
 EQUALS = =
 
 # The top-level source directory on which CMake was run.
-CMAKE_SOURCE_DIR = C:\Users\Tiny\Desktop\INSAGAME
+CMAKE_SOURCE_DIR = C:\Users\Tiny\Desktop\game-insa-project
 
 # The top-level build directory on which CMake was run.
-CMAKE_BINARY_DIR = C:\Users\Tiny\Desktop\INSAGAME\cmake-build-debug
+CMAKE_BINARY_DIR = C:\Users\Tiny\Desktop\game-insa-project\cmake-build-debug
 
 # Include any dependencies generated for this target.
 include CMakeFiles/INSAGAME.dir/depend.make
@@ -78,16 +78,16 @@ include CMakeFiles/INSAGAME.dir/flags.make
 
 CMakeFiles/INSAGAME.dir/main.c.obj: CMakeFiles/INSAGAME.dir/flags.make
 CMakeFiles/INSAGAME.dir/main.c.obj: ../main.c
-	@$(CMAKE_COMMAND) -E cmake_echo_color --switch=$(COLOR) --green --progress-dir=C:\Users\Tiny\Desktop\INSAGAME\cmake-build-debug\CMakeFiles --progress-num=$(CMAKE_PROGRESS_1) "Building C object CMakeFiles/INSAGAME.dir/main.c.obj"
-	C:\TDM-GCC-64\bin\gcc.exe $(C_DEFINES) $(C_INCLUDES) $(C_FLAGS) -o CMakeFiles\INSAGAME.dir\main.c.obj   -c C:\Users\Tiny\Desktop\INSAGAME\main.c
+	@$(CMAKE_COMMAND) -E cmake_echo_color --switch=$(COLOR) --green --progress-dir=C:\Users\Tiny\Desktop\game-insa-project\cmake-build-debug\CMakeFiles --progress-num=$(CMAKE_PROGRESS_1) "Building C object CMakeFiles/INSAGAME.dir/main.c.obj"
+	C:\TDM-GCC-64\bin\gcc.exe $(C_DEFINES) $(C_INCLUDES) $(C_FLAGS) -o CMakeFiles\INSAGAME.dir\main.c.obj   -c C:\Users\Tiny\Desktop\game-insa-project\main.c
 
 CMakeFiles/INSAGAME.dir/main.c.i: cmake_force
 	@$(CMAKE_COMMAND) -E cmake_echo_color --switch=$(COLOR) --green "Preprocessing C source to CMakeFiles/INSAGAME.dir/main.c.i"
-	C:\TDM-GCC-64\bin\gcc.exe $(C_DEFINES) $(C_INCLUDES) $(C_FLAGS) -E C:\Users\Tiny\Desktop\INSAGAME\main.c > CMakeFiles\INSAGAME.dir\main.c.i
+	C:\TDM-GCC-64\bin\gcc.exe $(C_DEFINES) $(C_INCLUDES) $(C_FLAGS) -E C:\Users\Tiny\Desktop\game-insa-project\main.c > CMakeFiles\INSAGAME.dir\main.c.i
 
 CMakeFiles/INSAGAME.dir/main.c.s: cmake_force
 	@$(CMAKE_COMMAND) -E cmake_echo_color --switch=$(COLOR) --green "Compiling C source to assembly CMakeFiles/INSAGAME.dir/main.c.s"
-	C:\TDM-GCC-64\bin\gcc.exe $(C_DEFINES) $(C_INCLUDES) $(C_FLAGS) -S C:\Users\Tiny\Desktop\INSAGAME\main.c -o CMakeFiles\INSAGAME.dir\main.c.s
+	C:\TDM-GCC-64\bin\gcc.exe $(C_DEFINES) $(C_INCLUDES) $(C_FLAGS) -S C:\Users\Tiny\Desktop\game-insa-project\main.c -o CMakeFiles\INSAGAME.dir\main.c.s
 
 # Object files for target INSAGAME
 INSAGAME_OBJECTS = \
@@ -101,7 +101,7 @@ INSAGAME.exe: CMakeFiles/INSAGAME.dir/build.make
 INSAGAME.exe: CMakeFiles/INSAGAME.dir/linklibs.rsp
 INSAGAME.exe: CMakeFiles/INSAGAME.dir/objects1.rsp
 INSAGAME.exe: CMakeFiles/INSAGAME.dir/link.txt
-	@$(CMAKE_COMMAND) -E cmake_echo_color --switch=$(COLOR) --green --bold --progress-dir=C:\Users\Tiny\Desktop\INSAGAME\cmake-build-debug\CMakeFiles --progress-num=$(CMAKE_PROGRESS_2) "Linking C executable INSAGAME.exe"
+	@$(CMAKE_COMMAND) -E cmake_echo_color --switch=$(COLOR) --green --bold --progress-dir=C:\Users\Tiny\Desktop\game-insa-project\cmake-build-debug\CMakeFiles --progress-num=$(CMAKE_PROGRESS_2) "Linking C executable INSAGAME.exe"
 	$(CMAKE_COMMAND) -E cmake_link_script CMakeFiles\INSAGAME.dir\link.txt --verbose=$(VERBOSE)
 
 # Rule to build all files generated by this target.
@@ -114,6 +114,6 @@ CMakeFiles/INSAGAME.dir/clean:
 .PHONY : CMakeFiles/INSAGAME.dir/clean
 
 CMakeFiles/INSAGAME.dir/depend:
-	$(CMAKE_COMMAND) -E cmake_depends "MinGW Makefiles" C:\Users\Tiny\Desktop\INSAGAME C:\Users\Tiny\Desktop\INSAGAME C:\Users\Tiny\Desktop\INSAGAME\cmake-build-debug C:\Users\Tiny\Desktop\INSAGAME\cmake-build-debug C:\Users\Tiny\Desktop\INSAGAME\cmake-build-debug\CMakeFiles\INSAGAME.dir\DependInfo.cmake --color=$(COLOR)
+	$(CMAKE_COMMAND) -E cmake_depends "MinGW Makefiles" C:\Users\Tiny\Desktop\game-insa-project C:\Users\Tiny\Desktop\game-insa-project C:\Users\Tiny\Desktop\game-insa-project\cmake-build-debug C:\Users\Tiny\Desktop\game-insa-project\cmake-build-debug C:\Users\Tiny\Desktop\game-insa-project\cmake-build-debug\CMakeFiles\INSAGAME.dir\DependInfo.cmake --color=$(COLOR)
 .PHONY : CMakeFiles/INSAGAME.dir/depend
 
diff --git a/cmake-build-debug/CMakeFiles/INSAGAME.dir/cmake_clean.cmake b/GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/cmake_clean.cmake
similarity index 100%
rename from cmake-build-debug/CMakeFiles/INSAGAME.dir/cmake_clean.cmake
rename to GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/cmake_clean.cmake
diff --git a/cmake-build-debug/CMakeFiles/INSAGAME.dir/depend.internal b/GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/depend.internal
similarity index 73%
rename from cmake-build-debug/CMakeFiles/INSAGAME.dir/depend.internal
rename to GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/depend.internal
index 1bbc4a9171f1e395e60fc230f7ef848ee9a513cc..3b7f2b1e4d851ab9cf7befe6b4b64397979030d3 100644
--- a/cmake-build-debug/CMakeFiles/INSAGAME.dir/depend.internal
+++ b/GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/depend.internal
@@ -2,4 +2,4 @@
 # Generated by "MinGW Makefiles" Generator, CMake Version 3.17
 
 CMakeFiles/INSAGAME.dir/main.c.obj
- C:/Users/Tiny/Desktop/INSAGAME/main.c
+ C:/Users/Tiny/Desktop/game-insa-project/main.c
diff --git a/cmake-build-debug/CMakeFiles/INSAGAME.dir/depend.make b/GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/depend.make
similarity index 100%
rename from cmake-build-debug/CMakeFiles/INSAGAME.dir/depend.make
rename to GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/depend.make
diff --git a/cmake-build-debug/CMakeFiles/INSAGAME.dir/flags.make b/GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/flags.make
similarity index 100%
rename from cmake-build-debug/CMakeFiles/INSAGAME.dir/flags.make
rename to GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/flags.make
diff --git a/cmake-build-debug/CMakeFiles/INSAGAME.dir/link.txt b/GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/link.txt
similarity index 100%
rename from cmake-build-debug/CMakeFiles/INSAGAME.dir/link.txt
rename to GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/link.txt
diff --git a/cmake-build-debug/CMakeFiles/INSAGAME.dir/linklibs.rsp b/GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/linklibs.rsp
similarity index 100%
rename from cmake-build-debug/CMakeFiles/INSAGAME.dir/linklibs.rsp
rename to GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/linklibs.rsp
diff --git a/GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/main.c.obj b/GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/main.c.obj
new file mode 100644
index 0000000000000000000000000000000000000000..2d22189c7d93704273352b1f7a665f86d9238615
Binary files /dev/null and b/GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/main.c.obj differ
diff --git a/GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/objects.a b/GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/objects.a
new file mode 100644
index 0000000000000000000000000000000000000000..b039ffdd100c315370a704009b76c5af3eb60467
Binary files /dev/null and b/GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/objects.a differ
diff --git a/cmake-build-debug/CMakeFiles/INSAGAME.dir/objects1.rsp b/GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/objects1.rsp
similarity index 100%
rename from cmake-build-debug/CMakeFiles/INSAGAME.dir/objects1.rsp
rename to GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/objects1.rsp
diff --git a/cmake-build-debug/CMakeFiles/INSAGAME.dir/progress.make b/GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/progress.make
similarity index 100%
rename from cmake-build-debug/CMakeFiles/INSAGAME.dir/progress.make
rename to GAME/cmake-build-debug/CMakeFiles/INSAGAME.dir/progress.make
diff --git a/cmake-build-debug/CMakeFiles/Makefile.cmake b/GAME/cmake-build-debug/CMakeFiles/Makefile.cmake
similarity index 100%
rename from cmake-build-debug/CMakeFiles/Makefile.cmake
rename to GAME/cmake-build-debug/CMakeFiles/Makefile.cmake
diff --git a/cmake-build-debug/CMakeFiles/Makefile2 b/GAME/cmake-build-debug/CMakeFiles/Makefile2
similarity index 90%
rename from cmake-build-debug/CMakeFiles/Makefile2
rename to GAME/cmake-build-debug/CMakeFiles/Makefile2
index 67c74b53d6b806a1b4afbb00e5f06892b0625416..28bd680cea44c822ea8c7f8f27c87659a4714228 100644
--- a/cmake-build-debug/CMakeFiles/Makefile2
+++ b/GAME/cmake-build-debug/CMakeFiles/Makefile2
@@ -63,10 +63,10 @@ RM = "C:\Program Files\JetBrains\CLion 2020.2.1\bin\cmake\win\bin\cmake.exe" -E
 EQUALS = =
 
 # The top-level source directory on which CMake was run.
-CMAKE_SOURCE_DIR = C:\Users\Tiny\Desktop\INSAGAME
+CMAKE_SOURCE_DIR = C:\Users\Tiny\Desktop\game-insa-project
 
 # The top-level build directory on which CMake was run.
-CMAKE_BINARY_DIR = C:\Users\Tiny\Desktop\INSAGAME\cmake-build-debug
+CMAKE_BINARY_DIR = C:\Users\Tiny\Desktop\game-insa-project\cmake-build-debug
 
 #=============================================================================
 # Directory level rules for the build root directory
@@ -93,14 +93,14 @@ clean: CMakeFiles/INSAGAME.dir/clean
 CMakeFiles/INSAGAME.dir/all:
 	$(MAKE) $(MAKESILENT) -f CMakeFiles\INSAGAME.dir\build.make CMakeFiles/INSAGAME.dir/depend
 	$(MAKE) $(MAKESILENT) -f CMakeFiles\INSAGAME.dir\build.make CMakeFiles/INSAGAME.dir/build
-	@$(CMAKE_COMMAND) -E cmake_echo_color --switch=$(COLOR) --progress-dir=C:\Users\Tiny\Desktop\INSAGAME\cmake-build-debug\CMakeFiles --progress-num=1,2 "Built target INSAGAME"
+	@$(CMAKE_COMMAND) -E cmake_echo_color --switch=$(COLOR) --progress-dir=C:\Users\Tiny\Desktop\game-insa-project\cmake-build-debug\CMakeFiles --progress-num=1,2 "Built target INSAGAME"
 .PHONY : CMakeFiles/INSAGAME.dir/all
 
 # Build rule for subdir invocation for target.
 CMakeFiles/INSAGAME.dir/rule: cmake_check_build_system
-	$(CMAKE_COMMAND) -E cmake_progress_start C:\Users\Tiny\Desktop\INSAGAME\cmake-build-debug\CMakeFiles 2
+	$(CMAKE_COMMAND) -E cmake_progress_start C:\Users\Tiny\Desktop\game-insa-project\cmake-build-debug\CMakeFiles 2
 	$(MAKE) $(MAKESILENT) -f CMakeFiles\Makefile2 CMakeFiles/INSAGAME.dir/all
-	$(CMAKE_COMMAND) -E cmake_progress_start C:\Users\Tiny\Desktop\INSAGAME\cmake-build-debug\CMakeFiles 0
+	$(CMAKE_COMMAND) -E cmake_progress_start C:\Users\Tiny\Desktop\game-insa-project\cmake-build-debug\CMakeFiles 0
 .PHONY : CMakeFiles/INSAGAME.dir/rule
 
 # Convenience name for target.
diff --git a/GAME/cmake-build-debug/CMakeFiles/TargetDirectories.txt b/GAME/cmake-build-debug/CMakeFiles/TargetDirectories.txt
new file mode 100644
index 0000000000000000000000000000000000000000..3cdf3ebc27f9c0c622de70c8bab059f0aa1ffdf7
--- /dev/null
+++ b/GAME/cmake-build-debug/CMakeFiles/TargetDirectories.txt
@@ -0,0 +1,3 @@
+C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/CMakeFiles/edit_cache.dir
+C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/CMakeFiles/INSAGAME.dir
+C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/CMakeFiles/rebuild_cache.dir
diff --git a/cmake-build-debug/CMakeFiles/clion-environment.txt b/GAME/cmake-build-debug/CMakeFiles/clion-environment.txt
similarity index 100%
rename from cmake-build-debug/CMakeFiles/clion-environment.txt
rename to GAME/cmake-build-debug/CMakeFiles/clion-environment.txt
diff --git a/cmake-build-debug/CMakeFiles/clion-log.txt b/GAME/cmake-build-debug/CMakeFiles/clion-log.txt
similarity index 63%
rename from cmake-build-debug/CMakeFiles/clion-log.txt
rename to GAME/cmake-build-debug/CMakeFiles/clion-log.txt
index db1dd2b50dd91b83d90738a48e9c6efe79891162..f3b2cb082abe6ee374a6d78803c204ca3524847f 100644
--- a/cmake-build-debug/CMakeFiles/clion-log.txt
+++ b/GAME/cmake-build-debug/CMakeFiles/clion-log.txt
@@ -1,4 +1,4 @@
-"C:\Program Files\JetBrains\CLion 2020.2.1\bin\cmake\win\bin\cmake.exe" -DCMAKE_BUILD_TYPE=Debug "-DCMAKE_MAKE_PROGRAM=C:/Program Files/Git/mingw64/bin/make.exe" -DCMAKE_C_COMPILER=C:/TDM-GCC-64/bin/gcc.exe -DCMAKE_CXX_COMPILER=C:/TDM-GCC-64/bin/g++.exe -G "CodeBlocks - MinGW Makefiles" C:\Users\Tiny\Desktop\INSAGAME
+"C:\Program Files\JetBrains\CLion 2020.2.1\bin\cmake\win\bin\cmake.exe" -DCMAKE_BUILD_TYPE=Debug "-DCMAKE_MAKE_PROGRAM=C:/Program Files/Git/mingw64/bin/make.exe" -DCMAKE_C_COMPILER=C:/TDM-GCC-64/bin/gcc.exe -DCMAKE_CXX_COMPILER=C:/TDM-GCC-64/bin/g++.exe -G "CodeBlocks - MinGW Makefiles" C:\Users\Tiny\Desktop\game-insa-project
 -- Configuring done
 -- Generating done
--- Build files have been written to: C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug
+-- Build files have been written to: C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug
diff --git a/cmake-build-debug/CMakeFiles/cmake.check_cache b/GAME/cmake-build-debug/CMakeFiles/cmake.check_cache
similarity index 100%
rename from cmake-build-debug/CMakeFiles/cmake.check_cache
rename to GAME/cmake-build-debug/CMakeFiles/cmake.check_cache
diff --git a/cmake-build-debug/CMakeFiles/progress.marks b/GAME/cmake-build-debug/CMakeFiles/progress.marks
similarity index 100%
rename from cmake-build-debug/CMakeFiles/progress.marks
rename to GAME/cmake-build-debug/CMakeFiles/progress.marks
diff --git a/cmake-build-debug/INSAGAME.cbp b/GAME/cmake-build-debug/INSAGAME.cbp
similarity index 52%
rename from cmake-build-debug/INSAGAME.cbp
rename to GAME/cmake-build-debug/INSAGAME.cbp
index c2d00f62f76c39d939f9ede763f0267eef309aab..b8932e7cf54b83d676e9e60de7128cc4014f1581 100644
--- a/cmake-build-debug/INSAGAME.cbp
+++ b/GAME/cmake-build-debug/INSAGAME.cbp
@@ -8,28 +8,28 @@
 		<Option virtualFolders="CMake Files\;"/>
 		<Build>
 			<Target title="all">
-				<Option working_dir="C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug"/>
+				<Option working_dir="C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug"/>
 				<Option type="4"/>
 				<MakeCommands>
-					<Build command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/Makefile&quot;  VERBOSE=1 all"/>
-					<CompileFile command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/Makefile&quot;  VERBOSE=1 &quot;$file&quot;"/>
-					<Clean command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/Makefile&quot;  VERBOSE=1 clean"/>
-					<DistClean command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/Makefile&quot;  VERBOSE=1 clean"/>
+					<Build command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/Makefile&quot;  VERBOSE=1 all"/>
+					<CompileFile command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/Makefile&quot;  VERBOSE=1 &quot;$file&quot;"/>
+					<Clean command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/Makefile&quot;  VERBOSE=1 clean"/>
+					<DistClean command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/Makefile&quot;  VERBOSE=1 clean"/>
 				</MakeCommands>
 			</Target>
 			<Target title="edit_cache">
-				<Option working_dir="C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug"/>
+				<Option working_dir="C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug"/>
 				<Option type="4"/>
 				<MakeCommands>
-					<Build command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/Makefile&quot;  VERBOSE=1 edit_cache"/>
-					<CompileFile command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/Makefile&quot;  VERBOSE=1 &quot;$file&quot;"/>
-					<Clean command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/Makefile&quot;  VERBOSE=1 clean"/>
-					<DistClean command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/Makefile&quot;  VERBOSE=1 clean"/>
+					<Build command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/Makefile&quot;  VERBOSE=1 edit_cache"/>
+					<CompileFile command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/Makefile&quot;  VERBOSE=1 &quot;$file&quot;"/>
+					<Clean command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/Makefile&quot;  VERBOSE=1 clean"/>
+					<DistClean command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/Makefile&quot;  VERBOSE=1 clean"/>
 				</MakeCommands>
 			</Target>
 			<Target title="INSAGAME">
-				<Option output="C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/INSAGAME.exe" prefix_auto="0" extension_auto="0"/>
-				<Option working_dir="C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug"/>
+				<Option output="C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/INSAGAME.exe" prefix_auto="0" extension_auto="0"/>
+				<Option working_dir="C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug"/>
 				<Option object_output="./"/>
 				<Option type="1"/>
 				<Option compiler="gcc"/>
@@ -40,15 +40,15 @@
 					<Add directory="C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/include"/>
 				</Compiler>
 				<MakeCommands>
-					<Build command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/Makefile&quot;  VERBOSE=1 INSAGAME"/>
-					<CompileFile command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/Makefile&quot;  VERBOSE=1 &quot;$file&quot;"/>
-					<Clean command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/Makefile&quot;  VERBOSE=1 clean"/>
-					<DistClean command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/Makefile&quot;  VERBOSE=1 clean"/>
+					<Build command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/Makefile&quot;  VERBOSE=1 INSAGAME"/>
+					<CompileFile command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/Makefile&quot;  VERBOSE=1 &quot;$file&quot;"/>
+					<Clean command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/Makefile&quot;  VERBOSE=1 clean"/>
+					<DistClean command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/Makefile&quot;  VERBOSE=1 clean"/>
 				</MakeCommands>
 			</Target>
 			<Target title="INSAGAME/fast">
-				<Option output="C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/INSAGAME.exe" prefix_auto="0" extension_auto="0"/>
-				<Option working_dir="C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug"/>
+				<Option output="C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/INSAGAME.exe" prefix_auto="0" extension_auto="0"/>
+				<Option working_dir="C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug"/>
 				<Option object_output="./"/>
 				<Option type="1"/>
 				<Option compiler="gcc"/>
@@ -59,27 +59,27 @@
 					<Add directory="C:/TDM-GCC-64/bin/../lib/gcc/x86_64-w64-mingw32/9.2.0/../../../../x86_64-w64-mingw32/include"/>
 				</Compiler>
 				<MakeCommands>
-					<Build command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/Makefile&quot;  VERBOSE=1 INSAGAME/fast"/>
-					<CompileFile command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/Makefile&quot;  VERBOSE=1 &quot;$file&quot;"/>
-					<Clean command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/Makefile&quot;  VERBOSE=1 clean"/>
-					<DistClean command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/Makefile&quot;  VERBOSE=1 clean"/>
+					<Build command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/Makefile&quot;  VERBOSE=1 INSAGAME/fast"/>
+					<CompileFile command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/Makefile&quot;  VERBOSE=1 &quot;$file&quot;"/>
+					<Clean command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/Makefile&quot;  VERBOSE=1 clean"/>
+					<DistClean command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/Makefile&quot;  VERBOSE=1 clean"/>
 				</MakeCommands>
 			</Target>
 			<Target title="rebuild_cache">
-				<Option working_dir="C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug"/>
+				<Option working_dir="C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug"/>
 				<Option type="4"/>
 				<MakeCommands>
-					<Build command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/Makefile&quot;  VERBOSE=1 rebuild_cache"/>
-					<CompileFile command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/Makefile&quot;  VERBOSE=1 &quot;$file&quot;"/>
-					<Clean command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/Makefile&quot;  VERBOSE=1 clean"/>
-					<DistClean command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/Makefile&quot;  VERBOSE=1 clean"/>
+					<Build command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/Makefile&quot;  VERBOSE=1 rebuild_cache"/>
+					<CompileFile command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/Makefile&quot;  VERBOSE=1 &quot;$file&quot;"/>
+					<Clean command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/Makefile&quot;  VERBOSE=1 clean"/>
+					<DistClean command="C:/PROGRA~1/Git/mingw64/bin/make.exe -f &quot;C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/Makefile&quot;  VERBOSE=1 clean"/>
 				</MakeCommands>
 			</Target>
 		</Build>
-		<Unit filename="C:/Users/Tiny/Desktop/INSAGAME/main.c">
+		<Unit filename="C:/Users/Tiny/Desktop/game-insa-project/main.c">
 			<Option target="INSAGAME"/>
 		</Unit>
-		<Unit filename="C:/Users/Tiny/Desktop/INSAGAME/CMakeLists.txt">
+		<Unit filename="C:/Users/Tiny/Desktop/game-insa-project/CMakeLists.txt">
 			<Option virtualFolder="CMake Files\"/>
 		</Unit>
 	</Project>
diff --git a/GAME/cmake-build-debug/INSAGAME.exe b/GAME/cmake-build-debug/INSAGAME.exe
new file mode 100644
index 0000000000000000000000000000000000000000..4a88bac7c40e6e59e8a7ac24ce1f18c7ecb7e1f0
Binary files /dev/null and b/GAME/cmake-build-debug/INSAGAME.exe differ
diff --git a/cmake-build-debug/Makefile b/GAME/cmake-build-debug/Makefile
similarity index 94%
rename from cmake-build-debug/Makefile
rename to GAME/cmake-build-debug/Makefile
index 529d240514fdb9ea74e2e97f6c7ae7d8c06bd551..32c88a87f2b0041ee78bee3283774aee3f3b9301 100644
--- a/cmake-build-debug/Makefile
+++ b/GAME/cmake-build-debug/Makefile
@@ -67,10 +67,10 @@ RM = "C:\Program Files\JetBrains\CLion 2020.2.1\bin\cmake\win\bin\cmake.exe" -E
 EQUALS = =
 
 # The top-level source directory on which CMake was run.
-CMAKE_SOURCE_DIR = C:\Users\Tiny\Desktop\INSAGAME
+CMAKE_SOURCE_DIR = C:\Users\Tiny\Desktop\game-insa-project
 
 # The top-level build directory on which CMake was run.
-CMAKE_BINARY_DIR = C:\Users\Tiny\Desktop\INSAGAME\cmake-build-debug
+CMAKE_BINARY_DIR = C:\Users\Tiny\Desktop\game-insa-project\cmake-build-debug
 
 #=============================================================================
 # Targets provided globally by CMake.
@@ -99,9 +99,9 @@ rebuild_cache/fast: rebuild_cache
 
 # The main all target
 all: cmake_check_build_system
-	$(CMAKE_COMMAND) -E cmake_progress_start C:\Users\Tiny\Desktop\INSAGAME\cmake-build-debug\CMakeFiles C:\Users\Tiny\Desktop\INSAGAME\cmake-build-debug\CMakeFiles\progress.marks
+	$(CMAKE_COMMAND) -E cmake_progress_start C:\Users\Tiny\Desktop\game-insa-project\cmake-build-debug\CMakeFiles C:\Users\Tiny\Desktop\game-insa-project\cmake-build-debug\CMakeFiles\progress.marks
 	$(MAKE) $(MAKESILENT) -f CMakeFiles\Makefile2 all
-	$(CMAKE_COMMAND) -E cmake_progress_start C:\Users\Tiny\Desktop\INSAGAME\cmake-build-debug\CMakeFiles 0
+	$(CMAKE_COMMAND) -E cmake_progress_start C:\Users\Tiny\Desktop\game-insa-project\cmake-build-debug\CMakeFiles 0
 .PHONY : all
 
 # The main clean target
diff --git a/cmake-build-debug/ressource/man.png b/GAME/cmake-build-debug/ressource/man.png
similarity index 100%
rename from cmake-build-debug/ressource/man.png
rename to GAME/cmake-build-debug/ressource/man.png
diff --git a/GAME/cmake-build-debug/ressource/map (2).bmp b/GAME/cmake-build-debug/ressource/map (2).bmp
new file mode 100644
index 0000000000000000000000000000000000000000..3bc26407b477e19480c10294a2a6041ee4d9cd93
Binary files /dev/null and b/GAME/cmake-build-debug/ressource/map (2).bmp differ
diff --git a/cmake-build-debug/ressource/map.bmp b/GAME/cmake-build-debug/ressource/map.bmp
similarity index 100%
rename from cmake-build-debug/ressource/map.bmp
rename to GAME/cmake-build-debug/ressource/map.bmp
diff --git a/cmake-build-debug/ressource/map.png b/GAME/cmake-build-debug/ressource/map.png
similarity index 100%
rename from cmake-build-debug/ressource/map.png
rename to GAME/cmake-build-debug/ressource/map.png
diff --git a/GAME/include/map.h b/GAME/include/map.h
new file mode 100644
index 0000000000000000000000000000000000000000..e69de29bb2d1d6434b8b29ae775ad8c2e48c5391
diff --git a/GAME/src/main.c b/GAME/src/main.c
new file mode 100644
index 0000000000000000000000000000000000000000..73b9c98140c1b0072d8b3058efee16cabb78c419
--- /dev/null
+++ b/GAME/src/main.c
@@ -0,0 +1,203 @@
+#include <stdio.h>
+#include <SDL2/SDL.h>
+#include <SDL2/SDL_image.h>
+
+#define WINDOW_WIDTH (1024)
+#define WINDOW_HEIGHT (1024)
+
+
+#define SPEED (450)
+
+int main(int argc, char* args[])
+{
+    // attempt to initialize graphics and timer system
+    if (SDL_Init(SDL_INIT_VIDEO|SDL_INIT_TIMER) != 0)
+    {
+        printf("error initializing SDL: %s\n", SDL_GetError());
+        return 1;
+    }
+
+    SDL_Window* win = SDL_CreateWindow("INSAGAME",
+                                       SDL_WINDOWPOS_CENTERED,
+                                       SDL_WINDOWPOS_CENTERED,
+                                       WINDOW_WIDTH, WINDOW_HEIGHT,0);
+    if (!win)
+    {
+        printf("error creating window: %s\n", SDL_GetError());
+        SDL_Quit();
+        return 1;
+    }
+
+    // create a renderer, which sets up the graphics hardware
+    Uint32 render_flags = SDL_RENDERER_ACCELERATED;
+    SDL_Renderer* rend = SDL_CreateRenderer(win, -1, render_flags);
+    if (!rend)
+    {
+        printf("error creating renderer: %s\n", SDL_GetError());
+        SDL_DestroyWindow(win);
+        SDL_Quit();
+        return 1;
+    }
+
+    // load the background into memory using SDL_image library function
+    SDL_Surface* background = IMG_Load("ressource/map (2).bmp");
+    if (!background)
+    {
+        printf("error creating surface\n");
+        SDL_DestroyRenderer(rend);
+        SDL_DestroyWindow(win);
+        SDL_Quit();
+        return 1;
+    }
+
+    // load the image data into the graphics hardware's memory
+    SDL_Texture* tex = SDL_CreateTextureFromSurface(rend, background);
+    SDL_FreeSurface(background);
+    if (!tex)
+    {
+        printf("error creating texture: %s\n", SDL_GetError());
+        SDL_DestroyRenderer(rend);
+        SDL_DestroyWindow(win);
+        SDL_Quit();
+        return 1;
+    }
+    SDL_Surface* man = IMG_Load("ressource/man.png");
+    if (!man)
+    {
+        printf("error creating surface\n");
+        SDL_DestroyRenderer(rend);
+        SDL_DestroyWindow(win);
+        SDL_Quit();
+        return 1;
+    }
+
+    // load the image data into the graphics hardware's memory
+    SDL_Texture* tex2 = SDL_CreateTextureFromSurface(rend, man);
+    SDL_FreeSurface(man);
+    if (!tex2)
+    {
+        printf("error creating texture: %s\n", SDL_GetError());
+        SDL_DestroyRenderer(rend);
+        SDL_DestroyWindow(win);
+        SDL_Quit();
+        return 1;
+    }
+    // struct to hold the position and size of the sprite
+    SDL_Rect dest;
+
+    // get and scale the dimensions of texture
+    SDL_QueryTexture(tex2, NULL, NULL, &dest.w, &dest.h);
+    dest.w /= 8;
+    dest.h /= 8;
+
+    // start sprite in center of screen
+    float x_pos = 70;
+    float y_pos = 70;
+    float x_vel = 0;
+    float y_vel = 0;
+
+    // keep track of which inputs are given
+    int up = 0;
+    int down = 0;
+    int left = 0;
+    int right = 0;
+
+    // set to 1 when window close button is pressed
+    int close_requested = 0;
+
+    // animation loop
+    while (!close_requested)
+    {
+        // process events
+        SDL_Event event;
+        while (SDL_PollEvent(&event))
+        {
+            switch (event.type)
+            {
+                case SDL_QUIT:
+                    close_requested = 1;
+                    break;
+                case SDL_KEYDOWN:
+                    switch (event.key.keysym.scancode)
+                    {
+                        case SDL_SCANCODE_W:
+                        case SDL_SCANCODE_UP:
+                            up = 1;
+                            break;
+                        case SDL_SCANCODE_A:
+                        case SDL_SCANCODE_LEFT:
+                            left = 1;
+                            break;
+                        case SDL_SCANCODE_S:
+                        case SDL_SCANCODE_DOWN:
+                            down = 1;
+                            break;
+                        case SDL_SCANCODE_D:
+                        case SDL_SCANCODE_RIGHT:
+                            right = 1;
+                            break;
+                    }
+                    break;
+                case SDL_KEYUP:
+                    switch (event.key.keysym.scancode)
+                    {
+                        case SDL_SCANCODE_W:
+                        case SDL_SCANCODE_UP:
+                            up = 0;
+                            break;
+                        case SDL_SCANCODE_A:
+                        case SDL_SCANCODE_LEFT:
+                            left = 0;
+                            break;
+                        case SDL_SCANCODE_S:
+                        case SDL_SCANCODE_DOWN:
+                            down = 0;
+                            break;
+                        case SDL_SCANCODE_D:
+                        case SDL_SCANCODE_RIGHT:
+                            right = 0;
+                            break;
+                    }
+                    break;
+            }
+        }
+
+        // determine velocity
+        x_vel = y_vel = 0;
+        if (up && !down) y_vel = -SPEED;
+        if (down && !up) y_vel = SPEED;
+        if (left && !right) x_vel = -SPEED;
+        if (right && !left) x_vel = SPEED;
+
+        // update positions
+        x_pos += x_vel / 60;
+        y_pos += y_vel / 60;
+
+        // collision detection with bounds
+        if (x_pos <= 0) x_pos = 0;
+        if (y_pos <= 0) y_pos = 0;
+        if (x_pos >= WINDOW_WIDTH - dest.w) x_pos = WINDOW_WIDTH - dest.w;
+        if (y_pos >= WINDOW_HEIGHT - dest.h) y_pos = WINDOW_HEIGHT - dest.h;
+
+        // set the positions in the struct
+        dest.y = (int) y_pos;
+        dest.x = (int) x_pos;
+
+        // clear the window
+        SDL_RenderClear(rend);
+
+        // draw the image to the window
+        SDL_RenderCopy(rend, tex, NULL, NULL);
+        SDL_RenderCopy(rend, tex2, NULL, &dest);
+        SDL_RenderPresent(rend);
+
+        // wait 1/60th of a second
+        SDL_Delay(1000/60);
+    }
+
+    // clean up resources before exiting
+    SDL_DestroyTexture(tex);
+    SDL_DestroyRenderer(rend);
+    SDL_DestroyWindow(win);
+    SDL_Quit();
+}
diff --git a/GAME/src/map.c b/GAME/src/map.c
new file mode 100644
index 0000000000000000000000000000000000000000..e69de29bb2d1d6434b8b29ae775ad8c2e48c5391
diff --git a/cmake-build-debug/CMakeFiles/INSAGAME.dir/main.c.obj b/cmake-build-debug/CMakeFiles/INSAGAME.dir/main.c.obj
deleted file mode 100644
index 4de99584c1ead23d393cf9032cb87a068b9aaf1a..0000000000000000000000000000000000000000
Binary files a/cmake-build-debug/CMakeFiles/INSAGAME.dir/main.c.obj and /dev/null differ
diff --git a/cmake-build-debug/CMakeFiles/INSAGAME.dir/objects.a b/cmake-build-debug/CMakeFiles/INSAGAME.dir/objects.a
deleted file mode 100644
index 819f340f725f20e6f183f39a1f957a0e0ccc9085..0000000000000000000000000000000000000000
Binary files a/cmake-build-debug/CMakeFiles/INSAGAME.dir/objects.a and /dev/null differ
diff --git a/cmake-build-debug/CMakeFiles/TargetDirectories.txt b/cmake-build-debug/CMakeFiles/TargetDirectories.txt
deleted file mode 100644
index 4db9908635fb74decf70b527453e9bc1fc5b3193..0000000000000000000000000000000000000000
--- a/cmake-build-debug/CMakeFiles/TargetDirectories.txt
+++ /dev/null
@@ -1,3 +0,0 @@
-C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/CMakeFiles/edit_cache.dir
-C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/CMakeFiles/INSAGAME.dir
-C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/CMakeFiles/rebuild_cache.dir
diff --git a/main.c b/main.c
deleted file mode 100644
index 17d734dd3d145e888b4f0173cd1625bfcd85b0ea..0000000000000000000000000000000000000000
--- a/main.c
+++ /dev/null
@@ -1,14 +0,0 @@
-#include <stdio.h>
-#include <SDL2/SDL.h>
-#include <SDL2/SDL_timer.h>
-#include <SDL2/SDL_image.h>
-
-
-int main(void)
-{
-   
-   
-   
-   
-   
-}
diff --git a/cmake-build-debug/cmake_install.cmake b/GAME/cmake-build-debug/cmake_install.cmake
similarity index 88%
rename from cmake-build-debug/cmake_install.cmake
rename to GAME/cmake-build-debug/cmake_install.cmake
index e4e5b26e9bd96470e4cc8be28e0bebe9ba7e6741..cb1c8352e8ea585986ee892c92a59680509ea8ae 100644
--- a/cmake-build-debug/cmake_install.cmake
+++ b/GAME/cmake-build-debug/cmake_install.cmake
@@ -1,4 +1,4 @@
 # Install script for directory: C:/Users/Tiny/Desktop/INSAGAME
 
 # Set the install prefix
 if(NOT DEFINED CMAKE_INSTALL_PREFIX)
@@ -40,5 +40,5 @@ endif()
 
 string(REPLACE ";" "\n" CMAKE_INSTALL_MANIFEST_CONTENT
        "${CMAKE_INSTALL_MANIFEST_FILES}")
-file(WRITE "C:/Users/Tiny/Desktop/INSAGAME/cmake-build-debug/${CMAKE_INSTALL_MANIFEST}"
+file(WRITE "C:/Users/Tiny/Desktop/game-insa-project/cmake-build-debug/${CMAKE_INSTALL_MANIFEST}"
      "${CMAKE_INSTALL_MANIFEST_CONTENT}")
@@ -1,4 +1,4 @@
-# Install script for directory: C:/Users/Tiny/Desktop/INSAGAME
+# Install script for directory: C:/Users/Tiny/Desktop/game-insa-project
 
 # Set the install prefix